@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -51,7 +51,7 @@ ConfigureCustomSettingWidget::ConfigureCustomSettingWidget(QWidget *parent)
     lab->setObjectName(QStringLiteral("categorytype_label"));
     categoryLayout->addWidget(lab);
 
-    mCategoryType = new CategoryTypeComboBox;
+    mCategoryType = new CategoryTypeComboBox(true, this);
     mCategoryType->setObjectName(QStringLiteral("categorytype_combobox"));
     categoryLayout->addWidget(mCategoryType);
 
@@ -73,20 +73,54 @@ void ConfigureCustomSettingWidget::slotTextChanged(const QString &text)
 
 void ConfigureCustomSettingWidget::setRule(const QString &rule)
 {
-    const Category cat = KDebugSettingsUtil::parseLineLoggingQtCategory(rule);
+    const KDebugSettingsUtil::LineLoggingQtCategory cat = KDebugSettingsUtil::parseLineLoggingQtCategory(rule);
     mCategoryLineEdit->setText(cat.logName);
     mEnableCategory->setChecked(cat.enabled);
-    mCategoryType->setType(cat.type);
+    switch (cat.type) {
+    case KDebugSettingsUtil::LineLoggingQtCategory::Unknown:
+        break;
+    case KDebugSettingsUtil::LineLoggingQtCategory::Info:
+        mCategoryType->setType(LoggingCategory::Info);
+        break;
+    case KDebugSettingsUtil::LineLoggingQtCategory::Warning:
+        mCategoryType->setType(LoggingCategory::Warning);
+        break;
+    case KDebugSettingsUtil::LineLoggingQtCategory::Debug:
+        mCategoryType->setType(LoggingCategory::Debug);
+        break;
+    case KDebugSettingsUtil::LineLoggingQtCategory::Critical:
+        mCategoryType->setType(LoggingCategory::Critical);
+        break;
+    case KDebugSettingsUtil::LineLoggingQtCategory::All:
+        mCategoryType->setType(LoggingCategory::All);
+        break;
+    }
 }
 
-QString ConfigureCustomSettingWidget::rule()
+QString ConfigureCustomSettingWidget::rule() const
 {
     QString ruleStr = mCategoryLineEdit->text().trimmed();
     if (!ruleStr.isEmpty()) {
-        const QString type = mCategoryType->type();
-        if (!type.isEmpty()) {
-            ruleStr += QLatin1Char('.') + type;
+        switch (mCategoryType->type()) {
+        case LoggingCategory::All:
+            break;
+        case LoggingCategory::Info:
+            ruleStr += QStringLiteral(".info");
+            break;
+        case LoggingCategory::Warning:
+            ruleStr += QStringLiteral(".warning");
+            break;
+        case LoggingCategory::Debug:
+            ruleStr += QStringLiteral(".debug");
+            break;
+        case LoggingCategory::Critical:
+            ruleStr += QStringLiteral(".critical");
+            break;
+        case LoggingCategory::Off:
+        case LoggingCategory::Undefined:
+            break;
         }
+
         if (mEnableCategory->isChecked()) {
             ruleStr += QStringLiteral("=true");
         } else {
