@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,6 +24,7 @@
 #include "environmentsettingsrulespage.h"
 #include "kdebugsettingsutil.h"
 #include "categorywarning.h"
+#include "loadcategoriesjob.h"
 
 #include <KLocalizedString>
 #include <KConfigGroup>
@@ -131,7 +132,7 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.categories"));
         Q_FOREACH (const QString &file, fileNames) {
             if (file != QStringLiteral("kde.categories")) {
-                KDebugSettingsUtil::readLoggingCategories(dir + file, mCategories);
+                KDebugSettingsUtil::readLoggingCategories(dir + file, mCategories, true);
             }
         }
     }
@@ -141,12 +142,12 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
     Q_FOREACH (const QString &dir, dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.categories"));
         Q_FOREACH (const QString &file, fileNames) {
-            KDebugSettingsUtil::readLoggingCategories(dir + QLatin1Char('/') + file, mCategories);
+            KDebugSettingsUtil::readLoggingCategories(dir + QLatin1Char('/') + file, mCategories, true);
         }
     }
     const QByteArray rulesFilePath = qgetenv("QT_LOGGING_CONF");
     if (!rulesFilePath.isEmpty()) {
-        const Category::List envCategories = KDebugSettingsUtil::readLoggingQtCategories(QString::fromLatin1(rulesFilePath));
+        const QList<KDebugSettingsUtil::LoadLoggingCategory> envCategories = KDebugSettingsUtil::readLoggingQtCategories(QString::fromLatin1(rulesFilePath));
         //TODO
     }
 
@@ -155,33 +156,16 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
         mEnvironmentSettingsRulesPage->setRules(environmentrules);
     }
     // qt logging.ini
-    const QString envPath = path;
-    Category::List customCategories;
-    bool foundOverrideRule = false;
-    if (!envPath.isEmpty()) {
-        const Category::List qtCategories = KDebugSettingsUtil::readLoggingQtCategories(envPath);
-        Q_FOREACH (const Category &cat, qtCategories) {
-            bool foundkde = false;
-            for (int i = 0; i < mCategories.count(); ++i) {
-                Category kdeCat = mCategories.at(i);
-                if (cat.logName == kdeCat.logName) {
-                    kdeCat.enabled = cat.enabled;
-                    kdeCat.type = cat.type;
-                    mCategories.replace(i, kdeCat);
-                    foundkde = true;
-                    break;
-                }
-            }
-            if (!foundkde) {
-                customCategories.append(cat);
-            }
-            if (cat.logName == QLatin1String("*")) {
-                foundOverrideRule = true;
-            }
-        }
-    }
+    LoadCategoriesJob job;
+    job.setFileName(path);
+    job.setCategories(mCategories);
+    job.start();
 
-    mKdeApplicationSettingsPage->fillList(mCategories);
+    const LoggingCategory::List customCategories = job.customCategories();
+    const LoggingCategory::List qtKdeCategories = job.qtKdeCategories();
+    const bool foundOverrideRule = job.foundOverrideRule();
+
+    mKdeApplicationSettingsPage->fillList(qtKdeCategories);
     mCustomSettingsPage->fillList(customCategories);
     if (foundOverrideRule) {
         mCategoryWarning->animatedShow();
@@ -196,15 +180,15 @@ bool KDebugSettingsDialog::saveRules(const QString &path)
         return false;
     }
     //Save Rules
-    const Category::List lstKde = mKdeApplicationSettingsPage->rules();
-    const Category::List lstCustom = mCustomSettingsPage->rules();
+    const LoggingCategory::List lstKde = mKdeApplicationSettingsPage->rules();
+    const LoggingCategory::List lstCustom = mCustomSettingsPage->rules();
     QTextStream out(&qtlogging);
     out << QLatin1String("[Rules]\n");
-    Q_FOREACH (Category cat, lstKde) {
+    Q_FOREACH (LoggingCategory cat, lstKde) {
         out << cat.createRule() + QLatin1Char('\n');
     }
-    Q_FOREACH (Category cat, lstCustom) {
-        out << cat.createRule() + QLatin1Char('\n');
+    Q_FOREACH (LoggingCategory cat, lstCustom) {
+        out << cat.createCustomRule() + QLatin1Char('\n');
     }
     return true;
 }
@@ -228,16 +212,6 @@ void KDebugSettingsDialog::slotHelpRequested()
     QDesktopServices::openUrl(QUrl(QStringLiteral("http://doc.qt.io/qt-5/qloggingcategory.html#details")));
 }
 
-QString Category::createRule()
-{
-    QString str = logName;
-    if (!type.isEmpty()) {
-        str += QLatin1Char('.') + type;
-    }
-    str += QLatin1String("=") + (enabled ? QLatin1Literal("true") : QLatin1Literal("false"));
-    return str;
-}
-
 void KDebugSettingsDialog::slotApply()
 {
     saveInQtLogging();
@@ -247,8 +221,17 @@ void KDebugSettingsDialog::slotInsertCategories()
 {
     const QString path = QFileDialog::getOpenFileName(this, i18n("Insert Categories"));
     if (!path.isEmpty()) {
-        const Category::List insertCategoriesList = KDebugSettingsUtil::readLoggingCategoriesForInserting(path, mCategories);
-        mKdeApplicationSettingsPage->insertCategories(insertCategoriesList);
+        const KdeLoggingCategory::List insertCategoriesList = KDebugSettingsUtil::readLoggingCategoriesForInserting(path, mCategories);
+        LoggingCategory::List newCategories;
+        Q_FOREACH (const KdeLoggingCategory &cat, insertCategoriesList) {
+            LoggingCategory loggingCat;
+            loggingCat.description = cat.description;
+            loggingCat.logName = cat.logName;
+            if (loggingCat.isValid()) {
+                newCategories.append(loggingCat);
+            }
+        }
+        mKdeApplicationSettingsPage->insertCategories(newCategories);
     }
 }
 
